OC.L10N.register(
    "core",
    {
    "Please select a file." : "Mesedez, hautatu fitxategi bat.",
    "File is too big" : "Fitxategia handiegia da",
    "The selected file is not an image." : "Aukeratutako fitxategia ez da irudi bat.",
    "The selected file cannot be read." : "Aukeratutako fitxategia ezin da irakurri.",
    "The file was uploaded" : "Fitxategia igo da",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Kargatutako fitxategiak php.ini fitxategiko upload_max_filesize direktiban zehazturikoa gainditzen du",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kargatutako fitxategiak HTML formularioan ezarritako MAX_FILE_SIZE direktiban zehazturikoa gainditzen du",
    "The file was only partially uploaded" : "Fitxategia erdizka kargatu da",
    "No file was uploaded" : "Ez da fitxategirik kargatu",
    "Missing a temporary folder" : "Aldi baterako karpeta bat falta da",
    "Could not write file to disk" : "Ezin izan da fitxategia diskoan idatzi",
    "A PHP extension stopped the file upload" : "PHP hedapen batek fitxategiaren karga gelditu du",
    "Invalid file provided" : "Baliogabeko fitxategia eman da",
    "No image or file provided" : "Ez da irudi edo fitxategirik zehaztu",
    "Unknown filetype" : "Fitxategi mota ezezaguna",
    "An error occurred. Please contact your admin." : "Errore bat gertatu da, jarri zure administratzailearekin kontaktuan.",
    "Invalid image" : "Baliogabeko irudia",
    "No temporary profile picture available, try again" : "Ez dago behin-behineko profil irudirik erabilgarri, saiatu berriro",
    "No crop data provided" : "Ez da mozketa daturik eman",
    "No valid crop data provided" : "Ez da baliozko mozketa daturik eman",
    "Crop is not square" : "Mozketa ez da karratua",
    "State token does not match" : "Egoera-tokena ez dator bat",
    "Invalid app password" : "Aplikazio pasahitza baliogabea",
    "Could not complete login" : "Ezin izan da saioa hasi",
    "Your login token is invalid or has expired" : "Zure saio-hasierako tokena baliogabea da edo iraungi da",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Nextcloud komunitate bertsio honek ez du laguntza-zerbitzurik eta push jakinarazpenak mugatuta daude.",
    "Login" : "Hasi saioa",
    "Password reset is disabled" : "Pasahitza berrezartzea desgaituta dago",
    "Could not reset password because the token is expired" : "Ezin izan da pasahitza berrezarri tokena iraungi delako",
    "Could not reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
    "%s password reset" : "%s pasahitza berrezarrita",
    "Password reset" : "Pasahitza berrezarri",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Egin klik ondoko botoian zure pasahitza berrezartzeko. Ez baduzu pasahitzaren berrezarpena eskatu, ahaztu e-posta hau.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Egin klik ondoko estekan zure pasahitza berrezartzeko. Ez baduzu pasahitzaren berrezarpena eskatu, ahaztu e-posta hau.",
    "Reset your password" : "Berrezarri zure pasahitza",
    "Nextcloud Server" : "Nextcloud zerbitzaria",
    "Some of your link shares have been removed" : "Zure esteka partekatzeetako batzuk kendu dira",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Segurtasun errore baten ondorioz zure esteka partekatze batzuk kendu ditugu. Ikusi esteka informazio gehiagorako.",
    "The user limit of this instance is reached." : "Instantzia honen erabiltzaile mugara iritsi da.",
    "Learn more ↗" : "Ikasi gehiago ↗",
    "Preparing update" : "Eguneratzea prestatzen",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Konponketa pausoa:",
    "Repair info:" : "Konponketa informazioa:",
    "Repair warning:" : "Konponketa abisua:",
    "Repair error:" : "Konponketa errorea:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Mesedez, erabili komando-lerroko eguneratzailea, eguneratze automatikoa config.php-n desgaituta dago eta.",
    "Turned on maintenance mode" : "Mantenu modua aktibatu da",
    "Turned off maintenance mode" : "Mantenu modua desaktibatu da",
    "Maintenance mode is kept active" : "Mantentze modua aktibatuta dago oraindik.",
    "Updating database schema" : "Datu-basearen eskema eguneratzen",
    "Updated database" : "Datu-basea eguneratuta",
    "Update app \"%s\" from App Store" : "Eguneratu \"%s\" aplikazioa App Store-tik",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s datu-basearen eskema eguneratu daitekeen egiaztatzen (honek luze jo dezake datu-basearen tamainaren arabera)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\" eguneratu da %2$s(e)ra",
    "Set log level to debug" : "Ezarri egunkari-maila arazketara",
    "Reset log level" : "Berrezarri egunkari-maila",
    "Starting code integrity check" : "Kodearen integritate egiaztapena hasten",
    "Finished code integrity check" : "Kodearen integritate egiaztapena bukatuta",
    "%s (incompatible)" : "%s (bateraezina)",
    "The following apps have been disabled: %s" : "Hurrengo aplikazioak desgaitu dira: %s",
    "Already up to date" : "Eguneratuta dago dagoeneko",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Zure web zerbitzaria ez dago behar bezala konfiguratuta fitxategien sinkronizazioa baimentzeko. WebDAV interfazea puskatuta dagoela dirudi.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Zure web zerbitzaria ez dago behar bezala konfiguratuta \"{url}\" ebazteko. Informazio gehiago {linkstart}dokumentazioa ↗{linkend}-(e)n aurkitu daiteke.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Zure web zerbitzaria ez dago behar bezala konfiguratuta \"{url}\" ebazteko. Ziur aski web zerbitzariaren konfigurazioa ez dago karpeta hau zuzenean entregatzeko eguneratuta. Konparatu zure konfigurazioa banatutako Apacherako \".htaccess\" fitxategiko berridazketa arauekin edo Nginx-en {linkstart}dokumentazio orria ↗{linkend} dokumentazioarekin. Nginx-en \"location ~\" katearekin hasten diren lerroak izan ohi dira eguneratu beharrekoak.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Zure web zerbitzaria ez dago behar bezala konfiguratuta .woff2 fitxategiak entregatzeko. Hau Nginx-en konfigurazioaren ohiko arazo bat da. Nextcloud 15ean doikuntza bat beharrezkoa da .woff2 fitxategiak bidaltzeko. Konparatu zure Nginx konfigurazioa gure {linkstart}dokumentazioa ↗{linkend}  gomendioarekin.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP sistemaren ingurune aldagaiak kontsultatu ahal izateko behar bezala konfiguratu gabe dagoela dirudi. Egindako getenv(\"PATH\") probak erantzun hutsa itzultzen du.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Mesedez, begiratu {link start} instalazio dokumentazioa ↗ {linked} PHP konfigurazio oharrak eta zure zerbitzariaren PHP konfigurazioa, batez ere php-fpm erabiltzean. ",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Irakurtzeko soilik konfigurazioa gaitu da. Honek web interfazetik konfigurazio batzuk ezartzea eragozten du. Gainera, eguneraketa bakoitzean fitxategia idazteko moduan jarri behar da eskuz.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Oraindik ez duzu posta elektronikoko zerbitzariaren konfigurazioa ezarri edo egiaztatu. Mesedez, joan {mailSettingsStart}Oinarrizko ezarpenetara{mailSettingsEnd} hauek ezartzeko. Ondoren, erabili inprimakiaren azpiko \"Bidali mezu elektronikoa\" botoia zure ezarpenak egiaztatzeko.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Zure datu-basea ez da \"READ COMMITTED\" transakzio isolamendu mailarekin exekutatzen. Honek arazoak eragin ditzake hainbat ekintza paraleloan exekutatzen direnean.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHPren \"fileinfo\" modulua falta da. Biziki gomendatzen da modulu hau gaitzea, MIME moten detekzioan emaitza hobeak lortzeko.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Transakzio-fitxategiak blokeatzea desgaituta dago, lasterketaren baldintzekin arazoak sor ditzake. Gaitu \"filelocking.enabled\" config.php-n arazo horiek saihesteko. Informazio gehiago lortzeko, ikusi {linkstart} dokumentazioa ↗ {linkend}.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Mesedez, ziurtatu zure config.php fitxategiko \"overwrite.cli.url\" aukera ezartzen duzula zure erabiltzaileek nagusiki Nextcloud honetara sartzeko erabiltzen duten URLan. Iradokizuna: \"{suggestedOverwriteCliURL}\". Bestela, URL-a sortzeko arazoak egon daitezke cron bidez. (Litekeena da iradokitako URLa ez izatea zure erabiltzaileek nagusiki Nextcloud honetara atzitzeko erabiltzen duten URLa. Edonola ere, hau egiaztatzea da onena.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Zure instalazioak ez du telefono eskualde lehenetsirik ezarrita. Hori beharrezkoa da baliozkotzeko profilaren ezarpenetan herrialde koderik gabeko telefono zenbakiak.  Herrialde koderik gabeko zenbakiak onartzeko, gehitu \"default_phone_region\" dagokion eskualdeko {linkstart} ISO 3166-1 kodea ↗ {linkend} zure konfigurazio fitxategian.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ezin izan da cron lana komando lerro bidez exekutatu. Ondorengo errore teknikoak gertatu dira:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Azken atzeko planaren exekuzioa {relativeTime} exekutatu da. Badirudi zerbait gaizki dagoela. {linkstart} Egiaztatu atzeko planoko ezarpenak ↗ {linkend}.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Hau laguntzarik gabeko Nextcloud komunitate bertsioa da. Instantzia honen tamaina kontuan hartuz, ezin da errendimendua, fidagarritasuna eta eskalabilitatea ziurtatu. Push jakinarazpenak mugatu egin dira gure doako zerbitzua ez gainkargatzeko. Ikusi Nextcloud Enterprise buruzko abantailak {linkstart}https://nextcloud.com/enterprise{linkend} orrian.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Zerbitzari honek ez dauka Interneteko konexiorik: hainbat amaiera-puntu ezin izan dira atzitu. Horren ondorioz, hainbat ezaugarrik ez dute funtzionatuko, hala nola, kanpoko biltegiratzeak muntatzeak, eguneraketei buruzko jakinarazpenak edo hirugarrengoen aplikazioak. Urruneko fitxategiak atzitzeak eta posta elektroniko bidezko jakinarazpenek ere ez dute funtzionatuko. Ezarri Interneterako konexioa zerbitzari honetan ezaugarri horiek izateko.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ez da memoria cachea konfiguratu. Errendimendua hobetzeko, konfiguratu memcache bat, erabilgarri badago. Informazio gehiago aurki dezakezu {linkstart} dokumentazioan ↗ {linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP-k ez du aurkitu iturri egokirik ausazkotasunerako, segurtasun arrazoiengatik oso gomendagarria dena. Informazio gehiago aurki dezakezu {linkstart} dokumentazioan ↗ {linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Une honetan PHP {version} exekutatzen ari zara. Bertsio-berritu zure PHP bertsioa PHP Group-ek link {linkend} eskaintzen dituen {linkstart} errendimendu eta segurtasun eguneratzeak aprobetxatzeko zure banaketak onartu bezain laster.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 da PHP 7.3 onartzen duen azken bertsioa. Nextcloud 24 PHP 7.4 behar du gutxienez.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Alderantzizko proxy goiburuko konfigurazioa okerra da, edo Nextcloud-era proxy fidagarri batetik sartzen ari zara. Hala ez bada, segurtasun arazo bat bada eta erasotzaile batek Nextcloud-en ikusgai dagoen IP helbidea faltsutzea baimendu dezake. Informazio gehiago aurkitu daiteke {linkstart} dokumentazioan ↗ {linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached banatutako cache gisa konfiguratuta dago, baina \"memcache\" PHP modulu okerra dago instalatuta. \\ OC \\ Memcache \\ Memcached-ek \"memcached\" soilik onartzen du eta ez \"memcache\". Ikusi bi moduluei buruzko {linkstart} memcached wikia ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Zenbait fitxategik ez dute integritate egiaztapena gainditu. Arazo hau konpontzeko moduari buruzko informazio gehiago aurki daiteke {linkstart1} dokumentazioan ↗ {linkend}. ({linkstart2} Baliogabeko fitxategien zerrenda...{linkend} / {linkstart3} Eskaneatu berriro...{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache modulua ez dago behar bezala konfiguratuta. Ikus {linkstart}dokumentazioa ↗{linkend} informazio gehiago lortzeko.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHPko \"set_time_limit\" funtzioa ez dago erabilgarri. Horren eraginez script-ak exekuzioaren erdian gelditu daitezke, zure instalazioa puskatuz. Biziki gomendatzen da funtzio hau gaitzea.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Zure PHPak ez dauka FreeType euskarririk. Ondorioz, profileko irudiak eta ezarpenen interfazea hondatuta daude.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "\"{indexName}\" indizea falta da \"{tableName}\" taulan.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Datu-baseak zenbait indize falta ditu. Taula handietan indizeak gehitzeak denbora dezente har dezakeenez ez dira automatikoki gehitu. \"occ db:add-missing-indices\" exekutatuz indize horiek eskuz gehitu daitezke instantzia martxan dagoen bitartean. Indizeak gehitu ondoren taula horietan egindako kontsultak askoz azkarragoak izan ohi dira.",
    "Missing primary key on table \"{tableName}\"." : "Gako nagusia falta da \"{tableName}\" taulan.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Datu-baseak zenbait gako nagusi falta ditu. Taula handietan datu nagusiak gehitzeak denbora dezente har dezakeenez ez dira automatikoki gehitu. Exekutatuz \"occ db:add-missing-primary-keys\" falta diren gako nagusi horiek eskuz gehitu daitezke instantzia martxan dagoen bitartean.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "\"{columnName}\" hautazko zutabea falta da \"{tableName}\" taulan.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Datu-baseak zenbait hautazko zutabe falta ditu. Hautazkoak izanik ez ziren automatikoki gehitu, taula handietan zutabeak gehitzeak denbora behar duelako. Zutabe horiek eskuz gehitu daitezke, instantzia martxan dagoen bitartean, \"occ db:add-missing-columns\" exekutatuz. Zutabeak gehitu ondoren, ezaugarri batzuk erantzuteko gaitasuna eta erabilgarritasuna hobetu dezakete.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Instantzia honek gomendatutako PHP modulu batzuk falta ditu. Biziki gomendatzen da horiek instalatzea, errendimendua eta bateragarritasuna hobetzeko.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "\"Imagick\" PHP modulua  ez dago gaituta, gaikako aplikazioa badago ere. Faviconen sorrerak behar bezala funtziona dezan, modulu hau instalatu eta gaitu behar duzu.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "\"gmp\" eta/edo \"bcmath\" PHP moduluak ez daude gaituta. WebAuthn pasahitz gabeko autentifikazioa erabiltzen baduzu, modulu hauek beharrezkoak dira.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Module php-imagick-ek ez du SVG onartzen instantzia honetan. Bateragarritasuna hobetzeko instalatzea gomendatzen da.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Datu baseko zutabe batzuek big int bihurtzea falta dute. Taula handietan zutabe motak aldatzeak denbora dezente har dezakeenez ez dira automatikoki aldatu. 'Occ db: convert-filecache-bigint' exekutatuz zain dauden aldaketak eskuz aplika litezke. Eragiketa hau instantzia lineaz kanpo dagoen bitartean egin behar da. Xehetasun gehiagorako, irakurri {linkstart} honi buruzko dokumentazio orria ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite datu-basea erabiltzen ari zara. Instalazio handiagoetarako beste datu-base sistema bat erabiltzea gomendatzen da.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Bereziki gomendagarria da mahaigaineko bezeroa fitxategien sinkronizaziorako erabiltzean.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Beste datu-base batera migratzeko, erabili komando lerroko tresna: \"occ db:convert-type\", edo ikusi {linkstart}dokumentazioa ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "PHPren memoria muga aholkatutako 512MB balioaren azpitik dago.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Zenbait aplikazio direktorio jabea ez dator bat web zerbitzariaren erabiltzailearekin. Aplikazio horiek eskuz instalatzean gerta daiteke hori. Egiaztatu baimenak ondorengo aplikazio direktorioetan:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL datu-base gisa erabiltzen da baina ez ditu 4 byteko karaktereak onartzen. 4 byteko karaktereak (emojiak bezala) fitxategien izenetan edo iruzkinetan arazorik gabe kudeatu ahal izateko, adibidez, 4 byteko euskarria gaitzea gomendatzen da MySQL-n. Xehetasun gehiagorako, irakurri {linkstart} honi buruzko dokumentazio orria ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Instantzia honek S3n oinarritutako objektuen biltegia erabiltzen du biltegiratze nagusi bezala. Kargatutako fitxategiak behin-behinean zerbitzarian gordetzen direnez, PHPren aldi baterako direktorioan 50 GB libre edukitzea gomendatzen da. Egiaztatu egunkariak bidearen eta erabilgarri dagoen espazioari buruzko xehetasunak izateko. Hobetzeko aldatu aldi baterako direktorioa php.ini fitxategian edo egin leku gehiago bide horretan.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Instantzia honen aldi baterako direktorioa existitzen edo idatzi ezin den direktorio batera erreferentziatzen du.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Zure instantziara konexio seguru baten bidez sartzen ari zara, hala ere, instantziak seguruak ez diren URLak sortzen ditu. Seguruenik horrek alderantzizko proxy baten atzean zaudela esan nahi du eta gainidatziaren konfigurazio aldagaiak ez daudela ondo ezarrita. Irakurri {linkstart} honi buruzko dokumentazio orria ↗ {linkend}.",
    "Error occurred while checking server setup" : "Errorea gertatu da zerbitzariaren konfigurazioa egiaztatzean",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Xehetasun gehiago lortzeko, ikusi {linkstart} dokumentazioa ↗ {linkedin}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Zure datuen direktorioa eta fitxategiak Internetetik atzitu daitezke. .htaccess fitxategiak ez du funtzionatzen. Biziki gomendatzen da  web zerbitzariaren konfigurazioa aldatzea datuen direktorioa atzigarri egon ez dadin edo datuen direktorioa web zerbitzariaren dokumentu errotik kanpora ateratzea.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP goiburua ez dago \"{expected}\" baliora ezarria. Hau segurtasun edo pribatutasun arrisku bat izan daiteke. Ezarpenean dagokion balioa jartzea gomendatzen da.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP goiburua ez dago \"{expected}\" baliora ezarria. Baliteke ezaugarri batzuk espero bezala ez funtzionatzea. Ezarpenean dagokion balioa jartzea gomendatzen da.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{expected}\" ez dago \"{header}\" HTTP goiburuaren barnean. Hau segurtasun edo pribatutasun arrisku bat izan daiteke. Ezarpenean dagokion balioa jartzea gomendatzen da.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "\"{Header}\" HTTP goiburua ez dago \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" edo \"{val5}\" gisa ezarrita. Horrek aipamenen informazioa isuri dezake. Ikusi {linkstart} W3C gomendioa ↗ {linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "\"Strict-Transport-Security\" HTTP goiburua ez dago gutxienez \"{segundo}\" segundotan ezarrita. Segurtasuna hobetzeko, HSTS gaitzea gomendatzen da {linkstart} segurtasun aholkuak ↗ {linkend} atalean azaltzen den moduan.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Gunera HTTP bidez modu ez-seguruan sartzen ari zara. Zure zerbitzaria derrigorrez HTTPS erabiltzeko konfiguratzea gomendatzen da biziki, {linkstart} segurtasun aholkuak ↗ {linkend} atalean azaltzen den moduan.",
    "unknown text" : "testu ezezaguna",
    "Hello world!" : "Kaixo mundua!",
    "sunny" : "eguzkitsua",
    "Hello {name}, the weather is {weather}" : "Kaixo {name}, eguraldia {weather} da",
    "Hello {name}" : "Kaixo {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Hauek dira zure bilaketaren emaitzak:<script>alert(1)</script></strong>",
    "new" : "berria",
    "_download %n file_::_download %n files_" : ["deskargatu fitxategi %n","deskargatu %n fitxategi"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Eguneratzea abian da, orri hau utziz gero prozesua eten liteke ingurune batzuetan.",
    "Update to {version}" : "Eguneratu {version} bertsiora",
    "An error occurred." : "Errore bat gertatu da.",
    "Please reload the page." : "Mesedez birkargatu orria.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Eguneraketak huts egin du. Informazio gehiagorako <a href=\"{url}\">begiratu gure  foroan arazoari buruzko sarrera</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Eguneraketak huts egin du. Mesedez, jakinarazi arazoa <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud komunitateari</a>.",
    "Continue to {productName}" : "Jarraitu hona: {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Eguneraketa behar bezala egin da. {ProductName} ra birbideratuko zaitugu %nsegundotan.","Eguneraketa behar bezala egin da. {ProductName} ra birbideratuko zaitugu %n segundotan."],
    "More apps" : "Aplikazio gehiago",
    "Currently open" : "Unean irekita",
    "_{count} notification_::_{count} notifications_" : ["Jakinarazpen {count}","{count} jakinarazpen"],
    "Log in" : "Hasi saioa",
    "Logging in …" : "Saioa hasten...",
    "Server side authentication failed!" : "Zerbitzari aldeko autentifikazioak huts egin du!",
    "Please contact your administrator." : "Mesedez jarri harremanetan zure administratzailearekin.",
    "An internal error occurred." : "Barne-errore bat gertatu da.",
    "Please try again or contact your administrator." : "Saiatu berriro edo jarri harremanetan administratzailearekin.",
    "Log in to {productName}" : "Hasi saioa {productName} -n",
    "Account name or email" : "Kontu izena edo emaila",
    "Password" : "Pasahitza",
    "Wrong username or password." : "Erabiltzaile-izen edo pasahitz okerra.",
    "User disabled" : "Erabiltzailea desgaituta",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Saioa hasteko hainbat saiakera baliogabe jaso ditugu zure IPtik. Ondorioz, zure hurrengo saio hasiera 30 segundo atzeratuko da.",
    "Username or email" : "Erabiltzaile-izena edo e-posta",
    "Your account is not setup for passwordless login." : "Zure kontua ez dago pasahitzik gabeko autentifikaziorako konfiguratua.",
    "Browser not supported" : "Ez da nabigatzailea onartzen",
    "Passwordless authentication is not supported in your browser." : "Zure nabigatzaileak ez du pasahitzik gabeko autentifikaziorik onartzen.",
    "Your connection is not secure" : "Zure konexioa ez da segurua",
    "Passwordless authentication is only available over a secure connection." : "Pasahitzik gabeko autentifikazioa konexio seguruetan erabil daiteke soilik.",
    "Reset password" : "Berrezarri pasahitza",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Pasahitza berrezartzeko mezu bat bidali da kontu honen helbide elektronikora. Jasotzen ez baduzu, egiaztatu spam/zabor karpetak edo eskatu laguntza administratzaile lokalari.",
    "If it is not there ask your local administrator." : "Han ez badago, galdetu zure administratzaile lokalari.",
    "Couldn't send reset email. Please contact your administrator." : "Ezin izan da berrezartzeko e-posta bidali. Jarri zure administratzailearekin harremanetan.",
    "Password cannot be changed. Please contact your administrator." : "Ezin da pasahitza aldatu. Jarri zure administratzailearekin harremanetan.",
    "Back to login" : "Itzuli saio hasierara",
    "New password" : "Pasahitz berria",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Zure fitxategiak enkriptatuta daude. Pasahitza berrezarri ondoren ezin izango dituzu zure datuak berreskuratu. Ez bazaude ziur, galdetu zure administratzaileari jarraitu aurretik. Ziur zaude jarraitu nahi duzula?",
    "I know what I'm doing" : "Badakit zer ari naizen egiten",
    "Resetting password" : "Pasahitza berrezartzen",
    "Recommended apps" : "Gomendatutako aplikazioak",
    "Loading apps …" : "Aplikazioak kargatzen...",
    "Could not fetch list of apps from the App Store." : "Ezin izan da aplikazioen zerrenda eskuratu App Store-tik.",
    "Installing apps …" : "Aplikazioak instalatzen...",
    "App download or installation failed" : "Huts egin du aplikazioaren deskarga edo instalazioak",
    "Cannot install this app because it is not compatible" : "Ezin da aplikazio hau instalatu ez delako bateragarria",
    "Cannot install this app" : "Ezin da aplikazio hau instalatu",
    "Skip" : "Saltatu",
    "Install recommended apps" : "Instalatu gomendatutako aplikazioak",
    "Schedule work & meetings, synced with all your devices." : "Antolatu lana eta bilerak, zure gailu guztiekin sinkronizatuta.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Eduki zure lankide eta lagun guztiak leku bakarrean, beren informazioa pribatu mantenduz.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Fitxategiak, Kontaktuak eta Egutegiarekin integratutako posta elektronikoko aplikazio soila.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Txata, bideo-deiak, pantaila partekatzea, lineako bilerak eta web konferentziak - zure nabigatzailean eta mugikorrerako aplikazioekin.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumentu, kalkulu-orri eta aurkezpen kolaboratiboak, Collabora Online-en sortuak.",
    "Forgot password?" : "Pasahitza ahaztu duzu?",
    "Log in with a device" : "Hasi saioa gailu batekin",
    "Back" : "Atzera",
    "Login form is disabled." : "Saioa hasteko inprimakia desgaituta dago.",
    "Edit Profile" : "Editatu profila",
    "The headline and about sections will show up here" : "Izenburua eta 'honi buruz' atalak hemen agertuko dira",
    "You have not added any info yet" : "Oraindik ez duzu informaziorik gehitu",
    "{user} has not added any info yet" : "{user} -ek ez du oraindik informaziorik gehitu",
    "Error opening the user status modal, try hard refreshing the page" : "Errorea erabiltzailen egoera leihoa irekitzen, saiatu orria guztiz freskatzen",
    "Search starts once you start typing" : "Idaztean hasten da bilaketarekin",
    "Reset search" : "Berrezarri bilaketa",
    "Start search" : "Hasi bilaketa",
    "Search for {name} only" : "Biatu {name} bakarrik",
    "No results for {query}" : " {query}-(r)entzako emaitzarik ez",
    "Press enter to start searching" : "Sakatu enter bilaketa hasteko",
    "Start typing to search" : "Hasi idazten bilatzeko",
    "Loading more results …" : "Emaitza gehiago kargatzen ...",
    "Load more results" : "Kargatu emaitza gehiago ",
    "Search" : "Bilatu",
    "An error occurred while searching for {type}" : "Errorea gertatu da {type} bilatzean",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Sartu karaktere {minSearchLength} edo gehiago bilatzeko","Sartu {minSearchLength} karaktere edo gehiago bilatzeko"],
    "Search {types} …" : "Bilatu  {types} …",
    "Settings" : "Ezarpenak",
    "Could not load your contacts" : "Ezin izan dira zure kontaktuak kargatu",
    "Search contacts …" : "Bilatu kontaktuak...",
    "No contacts found" : "Ez da kontakturik aurkitu",
    "Show all contacts …" : "Erakutsi kontaktu guztiak...",
    "Install the Contacts app" : "Instalatu kontaktuen aplikazioa",
    "Loading your contacts …" : "Zure kontaktuak kargatzen...",
    "Looking for {term} …" : "{term} bilatzen...",
    "No" : "Ez",
    "Yes" : "Bai",
    "No files in here" : "Ez dago fitxategirik hemen",
    "New folder" : "Karpeta berria",
    "No more subfolders in here" : "Ez dago azpikarpeta gehiagorik hemen",
    "Name" : "Izena",
    "Size" : "Tamaina",
    "Modified" : "Aldatua",
    "\"{name}\" is an invalid file name." : "\"{name}\" fitxategi-izen baliogabea da.",
    "File name cannot be empty." : "Fitxategi-izena ezin da hutsa izan.",
    "\"/\" is not allowed inside a file name." : "\"/\" ez da onartzen fitxategi-izenen barnean.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" fitxategi-mota ez da onartzen",
    "{newName} already exists" : "{newName} badago aurretik",
    "Choose" : "Aukeratu",
    "Copy" : "Kopiatu",
    "Move" : "Mugitu",
    "Error loading file picker template: {error}" : "Errorea fitxategi-hautatzailearen txantiloia kargatzerakoan: {error}",
    "OK" : "Ados",
    "Error loading message template: {error}" : "Errorea mezu txantiloia kargatzean: {error}",
    "read-only" : "irakurtzeko soilik",
    "_{count} file conflict_::_{count} file conflicts_" : ["fitxategi-gatazka {count}","{count} fitxategi-gatazka"],
    "One file conflict" : "Fitxategi-gatazka bat",
    "New Files" : "Fitxategi berriak",
    "Already existing files" : "Dagoeneko existitzen diren fitxategiak",
    "Which files do you want to keep?" : "Ze fitxategi mantendu nahi dituzu?",
    "If you select both versions, the copied file will have a number added to its name." : "Bi bertsioak hautatzen badituzu, kopiatutako fitxategiaren izenari zenbaki bat gehituko zaio.",
    "Cancel" : "Ezeztatu",
    "Continue" : "Jarraitu",
    "(all selected)" : "(denak hautatuta)",
    "({count} selected)" : "({count} hautatuta)",
    "Error loading file exists template" : "Errorea fitxategia existitzen da txantiloia kargatzean",
    "Show list view" : "Erakutsi zerrenda ikuspegia",
    "Show grid view" : "Erakutsi sareta-ikuspegia",
    "Pending" : "Zain",
    "Copy to {folder}" : "Kopiatu hona: {folder}",
    "Move to {folder}" : "Eraman hona: {folder}",
    "Saving …" : "Gordetzen …",
    "Authentication required" : "Autentifikazioa beharrezkoa da",
    "This action requires you to confirm your password" : "Ekintza honek zure pasahitza berrestea eskatzen du",
    "Confirm" : "Berretsi",
    "Failed to authenticate, try again" : "Autentifikazioak huts egin du, saiatu berriz",
    "seconds ago" : "segundo lehenago",
    "Connection to server lost" : "Zerbitzariarekiko konexioa eten da",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Arazoa orria kargatzerakoan, segundo %n barru berriz kargatuko da","Arazoa orria kargatzerakoan,  %n segundo barru berriz kargatuko da"],
    "Add to a project" : "Gehitu proiektu batera",
    "Show details" : "Erakutsi xehetasunak",
    "Hide details" : "Ezkutatu xehetasunak",
    "Rename project" : "Aldatu izena proiektuari",
    "Failed to rename the project" : "Huts egin du proiektuari izena aldatzean",
    "Failed to create a project" : "Huts egin du proiektu bat sortzean",
    "Failed to add the item to the project" : "Elementua proiektura gehitzeak huts egin du",
    "Connect items to a project to make them easier to find" : "Konektatu elementuak proiektu bati aurkitzen errazagoak izan daitezen",
    "Type to search for existing projects" : "Hasi idazten proiektuen artean bilatzeko",
    "New in" : "Berria hemen:",
    "View changelog" : "Ikusi aldaketen egunkaria",
    "Very weak password" : "Pasahitz oso ahula",
    "Weak password" : "Pasahitz ahula",
    "So-so password" : "Hala moduzko pasahitza",
    "Good password" : "Pasahitz ona",
    "Strong password" : "Pasahitz sendoa",
    "No action available" : "Ez dago ekintzarik eskuragarri",
    "Error fetching contact actions" : "Errorea kontaktu-ekintzak eskuratzean",
    "Non-existing tag #{tag}" : "#{tag} ez da existitzen",
    "Restricted" : "Mugatua",
    "Invisible" : "Ikusezina",
    "Delete" : "Ezabatu",
    "Rename" : "Berrizendatu",
    "Collaborative tags" : "Elkarlaneko etiketak",
    "No tags found" : "Ez da etiketarik aurkitu",
    "Personal" : "Pertsonala",
    "Users" : "Erabiltzaileak",
    "Apps" : "Aplikazioak",
    "Admin" : "Admin",
    "Help" : "Laguntza",
    "Access forbidden" : "Sarrera debekatuta",
    "Profile not found" : "Profila ez da aurkitu",
    "The profile does not exist." : "Profila ez da existitzen",
    "Back to %s" : "Itzuli %s(e)ra",
    "Page not found" : "Orria ez da aurkitu",
    "The page could not be found on the server." : "Orria ez da zerbitzarian aurkitu.",
    "Too many requests" : "Eskaera gehiegi",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Eskaera gehiegi zeuden zure saretik. Saiatu beranduago edo kontaktatu zure administrailearekin errorerik balego",
    "Error" : "Errorea",
    "Previous" : "Aurrekoa",
    "Internal Server Error" : "Zerbitzariaren barne-errorea",
    "The server was unable to complete your request." : "Zerbitzariak ezin izan du zure eskaera bete.",
    "If this happens again, please send the technical details below to the server administrator." : "Berriz gertatzen bada, mesedez bidali ondoko datu teknikoak zure administratzaileari.",
    "More details can be found in the server log." : "Xehetasun gehiago zerbitzariaren egunkarian aurki daitezke.",
    "Technical details" : "Xehetasun teknikoak",
    "Remote Address: %s" : "Urruneko helbidea: %s",
    "Request ID: %s" : "Eskariaren IDa: %s",
    "Type: %s" : "Mota: %s",
    "Code: %s" : "Kodea: %s",
    "Message: %s" : "Mezua: %s",
    "File: %s" : "Fitxategia: %s",
    "Line: %s" : "Lerroa: %s",
    "Trace" : "Arrastoa",
    "Security warning" : "Segurtasun abisua",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Zure datuen karpeta eta fitxategiak interneten bidez eskuragarri egon daitezke .htaccess fitxategia ez delako funtzionatzen ari.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Zerbitzaria behar bezala konfiguratzeari buruzko informazio gehiagorako, mesedez begira ezazu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentazioa</a>.",
    "Create an <strong>admin account</strong>" : "Sortu <strong>administratzaile kontu</strong> bat",
    "Username" : "Erabiltzaile-izena",
    "Show password" : "Erakutsi pasahitza",
    "Toggle password visibility" : "Txandakati pasahitzaren ikusgaitasuna",
    "Storage & database" : "Biltegia eta datu-basea",
    "Data folder" : "Datuen karpeta",
    "Configure the database" : "Konfiguratu datu-basea",
    "Only %s is available." : "Soilik %s dago eskuragarri.",
    "Install and activate additional PHP modules to choose other database types." : "Instalatu eta aktibatu PHP modulu osagarriak, beste datu-base mota aukeratzeko.",
    "For more details check out the documentation." : "Xehetasun gehiago nahi izanez gero, begiratu dokumentazioa.",
    "Database user" : "Datu-basearen erabiltzailea",
    "Database password" : "Datu-basearen pasahitza",
    "Database name" : "Datu-basearen izena",
    "Database tablespace" : "Datu-basearen taula-lekua",
    "Database host" : "Datu-basearen ostalaria",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zehaztu ataka makinaren izenarekin batera (adb. localhost:5432).",
    "Performance warning" : "Errendimendu abisua",
    "You chose SQLite as database." : "SQLite hautatu duzu datu-base gisa.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite garapenerako eta instantzia txikietarako soilik erabili behar litzateke. Produkziorako beste datu-base sistema bat erabiltzea gomendatzen dugu.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Fitxategiak sinkronizatzeko bezeroak erabiltzen badituzu, SQLite ez erabiltzea aholkatzen da.",
    "Install" : "Instalatu",
    "Installing …" : "Instalatzen ...",
    "Need help?" : "Laguntza behar duzu?",
    "See the documentation" : "Ikusi dokumentazioa",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Badirudi zure Nextcloud berrinstalatu nahian ari zarela. Hala ere CAN_INSTALL fitxategia ez da aurkitzen zure config direktorioan. Mesedez sor ezazu CAN_INSTALL fitxategia zure config karpetan jarraitu ahal izateko.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Ezin izan da CAN_INSTALL fitxategia config karpetatik ezabatu. Mesedez ezaba ezazu fitxategi hau eskuz.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikazio honek JavaScript eskatzen du ondo funtzionatzeko. Mesedez {linkstart}JavaScript gaitu{linkend} eta webgunea birkargatu.",
    "Skip to main content" : "Salto eduki nagusira",
    "Skip to navigation of app" : "Salto aplikazioaren nabigaziora",
    "Get your own free account" : "Eskuratu zure kontu propioa doan",
    "%s's homepage" : "%s-(r)en hasiera orria",
    "Contacts" : "Kontaktuak",
    "Contacts menu" : "Kontaktuen menua",
    "Open settings menu" : "Ireki ezarpenen menua",
    "Confirm your password" : "Berretsi pasahitza",
    "Connect to your account" : "Konektatu zure kontura",
    "Please log in before granting %1$s access to your %2$s account." : "Hasi saioa %1$s erabiltzaileari zure %2$s kontura sarbidea eman aurretik.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Gailu edo aplikazio berri bat konfiguratzen saiatzen ari ez bazara, norbaitek zure datuetarako sarbidea eman diezaiozun, zu engainatzen saiatzen ari da. Kasu horretan, jarraitu ordez jarri harremanetan sistemaren administratzailearekin.",
    "App token" : "Aplikazio-tokena",
    "Grant access" : "Baimendu sarrera",
    "Alternative log in using app token" : "Saio hasiera alternatiboa aplikazio-tokena erabiliz",
    "Account access" : "Kontuaren sarbidea",
    "Currently logged in as %1$s (%2$s)." : "Une honetan %1$s (%2$s) gisa hasi da saioa.",
    "You are about to grant %1$s access to your %2$s account." : "%1$s erabiltzaileari zure %2$s kontura sarbidea ematear zaude.",
    "Account connected" : "Kontua konektatuta",
    "Your client should now be connected!" : "Zure bezeroak konektatua behar luke orain!",
    "You can close this window." : "Leiho hau itxi dezakezu.",
    "This share is password-protected" : "Partekatutako hau pasahitzez babestua dago.",
    "The password is wrong or expired. Please try again or request a new one." : "Pasahitza oker dago edo iraungita dago. Mesedez, saiatu berriro edo eskatu berri bat.",
    "Please type in your email address to request a temporary password" : "Mesedez, idatzi zure helbide elektronikoa aldi baterako pasahitza eskatzeko",
    "Email address" : "Helbide elektronikoa",
    "Password sent!" : "Pasahitza bidalita!",
    "You are not authorized to request a password for this share" : "Ez duzu baimenik partekatze honetarako pasahitza eskatzeko",
    "Go to %s" : "%s-ra joan",
    "Two-factor authentication" : "Bi faktoreko autentifikazioa",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Segurtasun hobetua gaituta dago zure kontuan. Aukeratu autentifikaziorako bigarren faktore bat:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Ezin izan da kargatu zure bi faktoreko autentifikazio metodoetako bat gutxienez. Jarri harremanetan zure administratzailearekin.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Bi faktoreko autentifikazioa aplikatzen da baina ez da konfiguratu zure kontuan. Jarri harremanetan zure administratzailearekin laguntza jasotzeko.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Bi faktoreko autentifikazioa aplikatzen da baina ez da konfiguratu zure kontuan. Jarraitu bi pausoko autentifikazioa konfiguratzeko.",
    "Set up two-factor authentication" : "Konfiguratu bi faktoreko autentifikazioa",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Bi faktoreko autentifikazioa aplikatzen da baina ez da konfiguratu zure kontuan. Erabili zure ordezko kode bat saioa hasteko edo jarri harremanetan zure administratzailearekin laguntza jasotzeko.",
    "Use backup code" : "Erabili ordezko kodea",
    "Cancel login" : "Ezeztatu saio-hasiera",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Segurtasun hobetua aplikatzen da zure kontuan. Aukeratu hornitzailea konfiguratzeko:",
    "Error while validating your second factor" : "Errorea zure bigarren faktorea balioztatzean",
    "Access through untrusted domain" : "Domeinu ez-fidagarritik sartzen",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Jarri harremanetan zure administratzailearekin. Administratzailea bazara,  editatu \"trusted_domains\" ezarpena config/config.php fitxategian, config.sample.php adibidean bezala.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Hau konfiguratzeko informazio gehiago %1$sdokumentazioan%2$s aurki daiteke.",
    "App update required" : "Aplikazioa eguneratu behar da",
    "%1$s will be updated to version %2$s" : "%1$s %2$s bertsiora eguneratuko da.",
    "The following apps will be updated:" : "Hurrengo aplikazioak eguneratuko dira:",
    "These incompatible apps will be disabled:" : "Aplikazio bateraezin hauek desgaituko dira:",
    "The theme %s has been disabled." : "%s gaia desgaitu da.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ekin aurretik egiazta ezazu datu-basearen, ezarpenen karpetaren eta datuen karpetaren babeskopia egin duzula.",
    "Start update" : "Hasi eguneratzea",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Instalazio handietan denbora-mugak saihesteko, horren ordez ondoko komandoa exekuta dezakezu instalazioko direktoriotik:",
    "Detailed logs" : "Egunkari xehea",
    "Update needed" : "Eguneratzea beharrezkoa da",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Komando-lerroko eguneratzailea erabili mesedez, 50 erabiltzaile baino gehiagoko instantzia handia baita zurea.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Laguntzarako, ikusi <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentazioa</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Badakit web bidezko UI-a erabiliz eguneratzea egitean arriskuak daudela, eskaera denboraz-kanpo geratzen bada datuen galera gerta daitekeela, baina babeskopia kopia egin dut eta arazoak egonez gero badakit instantzia leheneratzen.",
    "Upgrade via web on my own risk" : "Web bidezko bertsio-berritzea nire ardurapean",
    "Maintenance mode" : "Mantentze modua",
    "This %s instance is currently in maintenance mode, which may take a while." : "%s instantzia hau mantenu-moduan dago une honetan, honek denbora tarte bat iraun dezake.",
    "This page will refresh itself when the instance is available again." : "Instantzia berriz ere erabilgarri dagoenean orri hau freskatuko da.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Jarri harremanetan zure sistema administratzailearekin mezu honek irauten badu edo ezustean agertu bada.",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Sartu zure harpidetza-gakoa erabiltzaile muga goratzeko. Nextcloud Enterprise-ri buruzko informazio gehiagorako ikusi gure webgunea.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Taula egiaztatzen %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Zerbitzari honek ez dauka Interneteko konexiorik: hainbat amaiera-puntu ezin izan dira atzitu. Horren ondorioz, hainbat ezaugarrik ez dute funtzionatuko, hala nola, kanpoko biltegiratzeak muntatzeak, eguneraketei buruzko jakinarazpenak edo hirugarrengoen aplikazioak. Urruneko fitxategiak atzitzeak eta posta elektroniko bidezko jakinarazpenek ere ez dute funtzionatuko. Ezarri Interneterako konexioa zerbitzari honetan ezaugarri horiek izateko.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud 20 da PHP 7.2rekin erabili daitekeen azken bertsioa. Nextcloud 21 erabiltzeko gutxienez PHP 7.3 behar da.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "PHP OPcache modulua ez dago kargatuta. {linkstart} Errendimendu hobea lortzeko, zure PHP instalazioan kargatzea gomendatzen da ↗{linked}.",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "PHP OPcache modulua ez dago behar bezala konfiguratuta. {linkstart} Errendimendu hobea lortzeko, ezarpen hauek erabiltzea gomendatzen da ↗ {linkend} ezarpen hauek <code>php.ini</code>-n erabiltzeko:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Datu baseko zutabe batzuek big int bihurtzea falta dute. Taula handietan zutabe motak aldatzeak denbora dezente har dezakeenez ez dira automatikoki aldatu. 'Occ db: convert-filecache-bigint' exekutatuz zain dauden aldaketak eskuz aplika litezke. Eragiketa hau instantzia lineaz kanpo dagoen bitartean egin behar da. Xehetasun gehiagorako, irakurri {linkstart} honi buruzko dokumentazio orria ↗{linkend}.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Beste datu-base batera migratzeko, erabili komando-lerroko tresna hau: 'occ db: convert-type', edo ikusi {linkstart} dokumentazioa ↗ {linkend}.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Zure datuen direktorioa eta fitxategiak Internetetik atzitu daitezke. .htaccess fitxategiak ez du funtzionatzen. Biziki gomendatzen da  web zerbitzariaren konfigurazioa aldatzea datuen direktorioa atzigarri egon ez dadin edo datuen direktorioa web zerbitzariaren dokumentu errotik kanpora ateratzea.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{expected}\" ez dago \"{header}\" HTTP goiburuaren barnean. Hau segurtasun edo pribatutasun arrisku bat izan daiteke. Ezarpenean dagokion balioa jartzea gomendatzen da.",
    "Collaboratively edit office documents." : "Editatu bulegoko dokumentuak elkarlanean.",
    "Local document editing back-end used by the Collabora Online app." : "Colabora Online aplikazioak dokumentu lokalak editatzeko erabiltzen duen atzealdekoa. ",
    "restricted" : "mugatua",
    "invisible" : "ikusezina",
    "File not found" : "Ez da fitxategia aurkitu",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Dokumentua ezin izan da aurkitu zerbitzarian. Agian partekatutakoa ezabatua izan da ala iraungitu egin da?",
    "More" : "Gehiago",
    "More apps menu" : "Aplikazio gehiago menua",
    "Settings menu" : "Ezarpenak menua",
    "The password is wrong. Try again." : "Pasahitza ez da zuzena. Saiatu berriro.",
    "Setup two-factor authentication" : "Konfiguratu bi faktoreko autentifikazioa",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Nextcloud komunitate bertsio honek ez du laguntza-zerbitzurik eta berehalako jakinarazpenak ez daude eskuragarri.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Hau laguntzarik gabeko Nextcloud komunitate bertsioa da. Instantzia honen tamaina kontuan hartuz, ezin da errendimendua, fidagarritasuna eta eskalabilitatea ziurtatu. Push jakinarazpenak desgaitu egin dira gure doako zerbitzua ez gainkargatzeko. Ikusi Nextcloud Enterprise buruzko abantailak nextcloud.com/enterprise orrian.",
    "You haven't added any info yet" : "Ez duzu informaziorik gehitu oraindik",
    "{user} hasn't added any info yet" : "{user} ez du informaziorik gehitu oraindik"
},
"nplurals=2; plural=(n != 1);");
